{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "5c180120",
   "metadata": {},
   "source": [
    "# Homework"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "366a6efa",
   "metadata": {},
   "source": [
    "## Starter code\n",
    "\n",
    "The following code performs K-Means clustering, with 5 clusters, like what we did in class, but with a few changes:\n",
    "* Instead of starting with a real dataset, we use `make_blobs` from `sklearn` to generate random data.\n",
    "* We specify explicit starting points.\n",
    "* We specify that the algorithm should only run the procedure one time; that is from the `max_iter = 1` step.\n",
    "* We also plot in black the 5 points used to assign the clusters.  (So for example, look at the black point in the green blob.  The points colored green are closer to that point than to any of the other four black points.  The next step in the algorithm will be to move the black points to the centers of the blobs, and then to re-color the other points.)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "c85a113b",
   "metadata": {},
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "import pandas as pd\n",
    "import altair as alt\n",
    "from sklearn.datasets import make_blobs\n",
    "from sklearn.cluster import KMeans"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "6b9b66e4",
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-461290f9be2c41559414789d171983b3\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-461290f9be2c41559414789d171983b3\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-461290f9be2c41559414789d171983b3\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"data\": {\"name\": \"data-a406b87c087de2dc5d32c6031b6dd878\"}, \"mark\": \"circle\", \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"c\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"a\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"b\"}}}, {\"data\": {\"name\": \"data-9e3c5bb93b8ecfed473a86410a84113f\"}, \"mark\": \"point\", \"encoding\": {\"color\": {\"value\": \"black\"}, \"shape\": {\"value\": \"diamond\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"a\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"b\"}}}], \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-a406b87c087de2dc5d32c6031b6dd878\": [{\"a\": -7.236323371135272, \"b\": -7.9662910588520495, \"c\": 2}, {\"a\": -12.224825135503115, \"b\": -5.6526821520855, \"c\": 2}, {\"a\": -6.000968681780013, \"b\": -3.2588690218248932, \"c\": 2}, {\"a\": -5.398595909796224, \"b\": -2.9655299955662517, \"c\": 2}, {\"a\": -1.8789751616277162, \"b\": 1.4133599988619974, \"c\": 1}, {\"a\": -1.7645992564372635, \"b\": 0.2128617694936521, \"c\": 1}, {\"a\": -7.074083727901138, \"b\": -7.486617419217934, \"c\": 2}, {\"a\": -0.9713438823692708, \"b\": 0.030110404653849843, \"c\": 0}, {\"a\": -1.1583891019679973, \"b\": 2.2429594203398535, \"c\": 3}, {\"a\": -2.2248886311762903, \"b\": 1.498614803701855, \"c\": 1}, {\"a\": -2.4897214911421877, \"b\": 2.434734019875065, \"c\": 3}, {\"a\": -0.46064202604701254, \"b\": 4.591646286327105, \"c\": 4}, {\"a\": -1.0967988093294934, \"b\": 4.647226961080894, \"c\": 4}, {\"a\": -7.298595088772781, \"b\": -2.521020719483392, \"c\": 2}, {\"a\": -12.074514525576655, \"b\": -3.0058473800175287, \"c\": 2}, {\"a\": -6.69977896754504, \"b\": -1.6371065508211105, \"c\": 2}, {\"a\": -0.7906737489426516, \"b\": 5.156901508708169, \"c\": 4}, {\"a\": -2.2415870726119733, \"b\": -1.4862806462784648, \"c\": 1}, {\"a\": -3.0167345870354216, \"b\": -0.3600984212505567, \"c\": 1}, {\"a\": -11.459116108375207, \"b\": -4.469696456009227, \"c\": 2}, {\"a\": -7.522529893352402, \"b\": -1.6265174763635708, \"c\": 2}, {\"a\": -2.9244775392541067, \"b\": 0.3384264690516508, \"c\": 1}, {\"a\": -6.6772633970161985, \"b\": -4.565684440324525, \"c\": 2}, {\"a\": -2.279560749896649, \"b\": 5.104521902915381, \"c\": 4}, {\"a\": -5.47348816398915, \"b\": -2.6929549080028967, \"c\": 2}, {\"a\": -7.278869965219267, \"b\": -7.007300750489723, \"c\": 2}, {\"a\": -5.500261248917603, \"b\": -4.325950160070423, \"c\": 2}, {\"a\": 0.10762000043485642, \"b\": -0.049319210863393415, \"c\": 0}, {\"a\": -10.280576055287947, \"b\": -4.2196754316819245, \"c\": 2}, {\"a\": -7.386613863222104, \"b\": -4.275337160084053, \"c\": 2}, {\"a\": -10.326764052994182, \"b\": -2.606243082692707, \"c\": 2}, {\"a\": -6.629883859394898, \"b\": -7.242804501620961, \"c\": 2}, {\"a\": -7.379446045575026, \"b\": -9.49823812489242, \"c\": 2}, {\"a\": -6.2941117791341625, \"b\": -2.8193880063341834, \"c\": 2}, {\"a\": -2.2218653369676096, \"b\": 6.361367943852196, \"c\": 4}, {\"a\": -0.9264777461055238, \"b\": 1.0717743447257781, \"c\": 0}, {\"a\": -11.396525322319578, \"b\": -3.8715807285575883, \"c\": 2}, {\"a\": -9.323316398832233, \"b\": -4.675740452777355, \"c\": 2}, {\"a\": -5.671759862319884, \"b\": -2.774353525386574, \"c\": 2}, {\"a\": -9.561726307356691, \"b\": -4.640835940423379, \"c\": 2}, {\"a\": -7.832685929682299, \"b\": -8.517766154330683, \"c\": 2}, {\"a\": -1.2360655518844066, \"b\": 4.483829937191721, \"c\": 4}, {\"a\": -1.9137397735558879, \"b\": 5.806333811324148, \"c\": 4}, {\"a\": -2.385157025082947, \"b\": 3.538721191219571, \"c\": 4}, {\"a\": -3.6163081545784195, \"b\": 2.199511866392906, \"c\": 1}, {\"a\": -5.847871443620898, \"b\": -3.4473742568043493, \"c\": 2}, {\"a\": -5.433190670026941, \"b\": -7.292336863605615, \"c\": 2}, {\"a\": -10.35693659936384, \"b\": -3.447966644610287, \"c\": 2}, {\"a\": -9.729008122919877, \"b\": -8.579656722257567, \"c\": 2}, {\"a\": -3.1678668616596877, \"b\": -0.31321641839590275, \"c\": 1}, {\"a\": -4.2360186328680225, \"b\": -3.4850787509816876, \"c\": 2}, {\"a\": -8.360140068938826, \"b\": -8.078907550941413, \"c\": 2}, {\"a\": -12.411215504826888, \"b\": -5.730914923169192, \"c\": 2}, {\"a\": -2.6501722621643142, \"b\": 2.264476246840215, \"c\": 3}, {\"a\": -11.046780248821717, \"b\": -3.63668965220655, \"c\": 2}, {\"a\": -7.424518560587725, \"b\": -2.6631628795280076, \"c\": 2}, {\"a\": -11.036894825688005, \"b\": -3.2203253156441263, \"c\": 2}, {\"a\": -7.164126686421097, \"b\": -2.9675305054354664, \"c\": 2}, {\"a\": -2.656579701478202, \"b\": 4.299695882063936, \"c\": 4}, {\"a\": -9.847696224925297, \"b\": -3.489814225631539, \"c\": 2}, {\"a\": -0.4603265722702603, \"b\": 0.5098441191610477, \"c\": 0}, {\"a\": -7.943088401134986, \"b\": -3.899939010564857, \"c\": 2}, {\"a\": -4.160972013327139, \"b\": -2.764231943209971, \"c\": 2}, {\"a\": -1.8319881134989553, \"b\": 3.5286314509217895, \"c\": 4}, {\"a\": -0.8062786839928973, \"b\": 3.9934605591321293, \"c\": 4}, {\"a\": -2.5139963629389945, \"b\": 1.8615860004370826, \"c\": 1}, {\"a\": -8.830637337653137, \"b\": -3.993017247453687, \"c\": 2}, {\"a\": -2.1066884707345177, \"b\": 5.63099757364866, \"c\": 4}, {\"a\": 0.00024227116135100424, \"b\": 5.148534029420497, \"c\": 4}, {\"a\": -2.363803786247451, \"b\": 1.0618261162289622, \"c\": 1}, {\"a\": -9.687440215869334, \"b\": -6.047596363586017, \"c\": 2}, {\"a\": -7.04371035506959, \"b\": -7.724569364990159, \"c\": 2}, {\"a\": -5.945305805685106, \"b\": -3.381364394498953, \"c\": 2}, {\"a\": -0.434020723247565, \"b\": 0.9491507641707977, \"c\": 0}, {\"a\": -5.7926200240131225, \"b\": -4.968072450589213, \"c\": 2}, {\"a\": -8.839478171882572, \"b\": -8.465457766001856, \"c\": 2}, {\"a\": -7.587238648793434, \"b\": -8.522484006453013, \"c\": 2}, {\"a\": -3.323000432669585, \"b\": 0.14254262637045279, \"c\": 1}, {\"a\": -5.6358664530267735, \"b\": -3.554445191572878, \"c\": 2}, {\"a\": -12.142156550381552, \"b\": -4.322910972700638, \"c\": 2}, {\"a\": -6.968768041318218, \"b\": -8.001175763690616, \"c\": 2}, {\"a\": -4.044521624644903, \"b\": -3.6375462882914302, \"c\": 2}, {\"a\": -0.7920271840921072, \"b\": -0.22223173472206603, \"c\": 0}, {\"a\": -9.500443405007124, \"b\": -3.716015848023608, \"c\": 2}, {\"a\": -0.15258176884950525, \"b\": 0.6459927477851327, \"c\": 0}, {\"a\": -2.3315808110363454, \"b\": 1.48549185194019, \"c\": 1}, {\"a\": 1.371297206423511, \"b\": 5.231074493876619, \"c\": 4}, {\"a\": -6.654009245658668, \"b\": -7.961864189485125, \"c\": 2}, {\"a\": -6.964490461258191, \"b\": -7.831902271161457, \"c\": 2}, {\"a\": -0.6732247181272776, \"b\": 4.620023770178603, \"c\": 4}, {\"a\": -10.59105625789552, \"b\": -3.4430409506179487, \"c\": 2}, {\"a\": -6.788779429734464, \"b\": -8.40024459550978, \"c\": 2}, {\"a\": -7.904871098269986, \"b\": -10.451433985161897, \"c\": 2}, {\"a\": -2.176949598773941, \"b\": 1.5804575310876123, \"c\": 1}, {\"a\": -2.3302221922375503, \"b\": 4.784053655164081, \"c\": 4}, {\"a\": -1.9860594040267037, \"b\": 3.0638140794657254, \"c\": 3}, {\"a\": -2.5279884832229325, \"b\": 1.0732920478244485, \"c\": 1}, {\"a\": -5.3810116670655415, \"b\": -2.139517372905664, \"c\": 2}, {\"a\": -2.1031329776713807, \"b\": 0.29360781770159033, \"c\": 1}, {\"a\": -1.2213935586572822, \"b\": 5.528818190500254, \"c\": 4}, {\"a\": -7.267576091365201, \"b\": -8.007576287337557, \"c\": 2}, {\"a\": -1.2932278914084612, \"b\": 3.3619004869353697, \"c\": 4}, {\"a\": -3.134938806982681, \"b\": 0.6625531157533896, \"c\": 1}, {\"a\": -2.6997379345337977, \"b\": -0.1180359637417534, \"c\": 1}, {\"a\": -7.8008309604291854, \"b\": -3.8508702643841763, \"c\": 2}, {\"a\": -5.417248218856188, \"b\": -2.950900591229217, \"c\": 2}, {\"a\": -0.9007542458505886, \"b\": 5.291398683308045, \"c\": 4}, {\"a\": -5.234757317912102, \"b\": -2.5155200106140048, \"c\": 2}, {\"a\": -1.564134818757262, \"b\": 5.327939937502673, \"c\": 4}, {\"a\": -6.26408334581885, \"b\": -2.5446613755514917, \"c\": 2}, {\"a\": -0.9190034548522448, \"b\": 3.452789267035227, \"c\": 4}, {\"a\": -4.402492510171256, \"b\": -2.320967330148182, \"c\": 1}, {\"a\": -6.701534265083474, \"b\": -9.132948296069024, \"c\": 2}, {\"a\": -6.462422121557808, \"b\": -3.23772668828352, \"c\": 2}, {\"a\": -1.8684541393232976, \"b\": 4.993113060025359, \"c\": 4}, {\"a\": -7.42029567414988, \"b\": -8.054285858591548, \"c\": 2}, {\"a\": -6.89082771749601, \"b\": -7.975282546662434, \"c\": 2}, {\"a\": -1.84048020802667, \"b\": 3.802569241049904, \"c\": 4}, {\"a\": -8.461176175632003, \"b\": -3.953723556121561, \"c\": 2}, {\"a\": -1.7440679333531492, \"b\": 4.109127986069658, \"c\": 4}, {\"a\": -9.53106923642426, \"b\": -2.9196616794237036, \"c\": 2}, {\"a\": -8.85261989207558, \"b\": -8.339038961404373, \"c\": 2}, {\"a\": -0.010175753401293175, \"b\": 0.18476842980041264, \"c\": 0}, {\"a\": 0.08525185826796045, \"b\": 3.6452829679480585, \"c\": 3}, {\"a\": -7.681628608718905, \"b\": -8.166532325931541, \"c\": 2}, {\"a\": -1.5751338972448141, \"b\": 1.0151305375900894, \"c\": 1}, {\"a\": -4.965863438165082, \"b\": -2.3557128985965985, \"c\": 2}, {\"a\": -2.8264852059650494, \"b\": -0.18319714282779642, \"c\": 1}, {\"a\": -1.8513954583101344, \"b\": 3.5188609047583252, \"c\": 4}, {\"a\": -3.2298685174166377, \"b\": 0.3509156552621781, \"c\": 1}, {\"a\": -9.008803941989527, \"b\": -9.327251781166888, \"c\": 2}, {\"a\": -1.6841768618242978, \"b\": 3.631328249674002, \"c\": 4}, {\"a\": -2.16635962914775, \"b\": -1.0229644494842474, \"c\": 1}, {\"a\": -10.372517190955755, \"b\": -4.703318164638871, \"c\": 2}, {\"a\": -2.0171158932215008, \"b\": 1.0096144071231807, \"c\": 1}, {\"a\": -7.188239182101356, \"b\": -3.712690611807707, \"c\": 2}, {\"a\": -1.1014574182461794, \"b\": -1.1867403878814606, \"c\": 0}, {\"a\": -10.298688657608439, \"b\": -3.1458926303579346, \"c\": 2}, {\"a\": -3.562845898551427, \"b\": -4.186934091696264, \"c\": 2}, {\"a\": -5.887829927881097, \"b\": -8.794335919821934, \"c\": 2}, {\"a\": -8.43542377674625, \"b\": -2.6821298097905064, \"c\": 2}, {\"a\": -7.7113732104417325, \"b\": -9.60221965314609, \"c\": 2}, {\"a\": -10.10417262520864, \"b\": -6.744344954057051, \"c\": 2}, {\"a\": -10.412559404941337, \"b\": -3.5014025100419817, \"c\": 2}, {\"a\": -10.62305450511909, \"b\": -4.547191614617715, \"c\": 2}, {\"a\": -6.05691570605716, \"b\": -7.760893193499737, \"c\": 2}, {\"a\": -10.797259994344861, \"b\": -4.244943142864037, \"c\": 2}, {\"a\": -5.7280655065301564, \"b\": -3.5661671213717057, \"c\": 2}, {\"a\": -2.406293766685311, \"b\": 0.20430879285404457, \"c\": 1}, {\"a\": -10.765022329984836, \"b\": -3.278777840407201, \"c\": 2}, {\"a\": -10.590173788806371, \"b\": -6.258256485133343, \"c\": 2}, {\"a\": -5.8365543794290495, \"b\": -3.5098823442048586, \"c\": 2}, {\"a\": -0.6207353040891055, \"b\": 6.59346951581742, \"c\": 4}, {\"a\": -2.8121767839662017, \"b\": 0.18965424036968292, \"c\": 1}, {\"a\": -0.27078050957825117, \"b\": 3.7451456256901428, \"c\": 4}, {\"a\": -7.894441466267239, \"b\": -1.0836449335924532, \"c\": 2}, {\"a\": -1.8959968577615063, \"b\": 5.134303368842811, \"c\": 4}, {\"a\": -11.268173280038582, \"b\": -3.670353013552203, \"c\": 2}, {\"a\": -9.685473814640101, \"b\": -4.146670187837208, \"c\": 2}, {\"a\": -1.9513022602133105, \"b\": 0.45159241602617123, \"c\": 1}, {\"a\": -1.846572017600432, \"b\": 0.45851911375235743, \"c\": 1}, {\"a\": -8.47409146012993, \"b\": -7.0225027500949135, \"c\": 2}, {\"a\": -6.277543168174556, \"b\": -1.7536441314204134, \"c\": 2}, {\"a\": -11.157882608635378, \"b\": -2.6032417286814784, \"c\": 2}, {\"a\": -3.103673711378109, \"b\": 3.90202400589671, \"c\": 4}, {\"a\": -11.94275946226514, \"b\": -4.868772915594911, \"c\": 2}, {\"a\": -1.5754313216301088, \"b\": -0.3404975771691112, \"c\": 1}, {\"a\": -6.587398786111654, \"b\": -2.987582372640725, \"c\": 2}, {\"a\": -1.0005101098483093, \"b\": 2.779051528226904, \"c\": 3}, {\"a\": -9.856071965987296, \"b\": -6.469652408328954, \"c\": 2}, {\"a\": -7.263819633941635, \"b\": -7.8512680592179, \"c\": 2}, {\"a\": -2.502914464407433, \"b\": 0.7555814184687154, \"c\": 1}, {\"a\": -7.597238743788832, \"b\": -2.4859224568517004, \"c\": 2}, {\"a\": -4.955069860474657, \"b\": -2.1748346442599282, \"c\": 2}, {\"a\": -6.39226243553626, \"b\": -5.724351135101066, \"c\": 2}, {\"a\": -5.909620428239588, \"b\": -7.807170358339371, \"c\": 2}, {\"a\": -8.986505439878194, \"b\": -5.429911207883385, \"c\": 2}, {\"a\": -8.617580966834574, \"b\": -7.574763684367803, \"c\": 2}, {\"a\": -6.671921455302725, \"b\": -2.202695538932053, \"c\": 2}, {\"a\": -1.6816236456293954, \"b\": 1.7176602646166779, \"c\": 3}, {\"a\": -8.895475771067758, \"b\": -5.182922800909633, \"c\": 2}, {\"a\": -6.478263665056894, \"b\": -6.97804941706669, \"c\": 2}, {\"a\": -10.181112700973125, \"b\": -2.8523483446947226, \"c\": 2}, {\"a\": -6.775506138040109, \"b\": -4.112147660625892, \"c\": 2}, {\"a\": -9.889681686340756, \"b\": -3.923930928392439, \"c\": 2}, {\"a\": -10.382544752485892, \"b\": -2.4952403087536847, \"c\": 2}, {\"a\": -5.346505557521516, \"b\": -3.0053966219031354, \"c\": 2}, {\"a\": 0.1751577207011672, \"b\": 4.970872724337475, \"c\": 4}, {\"a\": -5.629643119318004, \"b\": -1.8066436290497245, \"c\": 2}, {\"a\": -4.961900360916854, \"b\": -3.065428431569387, \"c\": 2}, {\"a\": -7.264442901653955, \"b\": -8.807831273149024, \"c\": 2}, {\"a\": -0.2081306453575842, \"b\": 3.788453021161583, \"c\": 4}, {\"a\": -0.6494327286137951, \"b\": 5.326507802090925, \"c\": 4}, {\"a\": -5.19370277942549, \"b\": -1.3643937391871577, \"c\": 1}, {\"a\": -6.206870731566657, \"b\": -9.512024945725974, \"c\": 2}, {\"a\": -2.2010230251431, \"b\": -0.5929457251461856, \"c\": 1}, {\"a\": -10.377230019186982, \"b\": -4.968152238221876, \"c\": 2}, {\"a\": -1.0049797533618192, \"b\": 4.355301421235497, \"c\": 4}, {\"a\": -10.867720726843954, \"b\": -3.5841580778163307, \"c\": 2}, {\"a\": -12.14017923273047, \"b\": -4.783517411385913, \"c\": 2}, {\"a\": -2.9915115724657677, \"b\": 2.645801308444378, \"c\": 3}, {\"a\": -7.59500198385779, \"b\": -8.560468128635975, \"c\": 2}, {\"a\": -4.901463317320472, \"b\": -3.6162049161060454, \"c\": 2}, {\"a\": -7.118707260384386, \"b\": -4.262195365471139, \"c\": 2}, {\"a\": -4.651333669153496, \"b\": -1.932341852745398, \"c\": 1}, {\"a\": -8.48921585883874, \"b\": -6.859045791364871, \"c\": 2}, {\"a\": -1.1310208871777154, \"b\": -0.9874400356841515, \"c\": 0}, {\"a\": -5.351039803382617, \"b\": -5.542677389470311, \"c\": 2}, {\"a\": -6.875300111070864, \"b\": -3.7374212267406217, \"c\": 2}, {\"a\": -1.7755450914209159, \"b\": 4.231030900181409, \"c\": 4}, {\"a\": -10.01516745548928, \"b\": -3.221946030238139, \"c\": 2}, {\"a\": -1.646207229601343, \"b\": 3.7117962735559353, \"c\": 4}, {\"a\": -1.6462885987530027, \"b\": 1.5057777538481254, \"c\": 3}, {\"a\": -1.5817387780358136, \"b\": 5.024870130841686, \"c\": 4}, {\"a\": -10.475293358309822, \"b\": -3.9273485531775463, \"c\": 2}, {\"a\": -9.217685368314472, \"b\": -4.582790151416985, \"c\": 2}, {\"a\": -7.494268156870752, \"b\": -8.627817971703452, \"c\": 2}, {\"a\": -5.981223685198326, \"b\": -3.4501893196741844, \"c\": 2}, {\"a\": -5.407757545614813, \"b\": -6.735554091624684, \"c\": 2}, {\"a\": -1.4168904648667249, \"b\": 4.608320047717165, \"c\": 4}, {\"a\": -5.568997417773263, \"b\": -7.477774295419833, \"c\": 2}, {\"a\": -2.1349327810865018, \"b\": 4.884100050660718, \"c\": 4}, {\"a\": -6.080869946717498, \"b\": -8.712909526542601, \"c\": 2}, {\"a\": -6.383694239284625, \"b\": -2.1512306162712984, \"c\": 2}, {\"a\": -7.1983708530238, \"b\": -6.166662993681645, \"c\": 2}, {\"a\": -0.02497824967997664, \"b\": 2.373106578088791, \"c\": 3}, {\"a\": -1.8461296778558682, \"b\": 4.304743996314016, \"c\": 4}, {\"a\": -6.08624245716642, \"b\": -3.0419541011416036, \"c\": 2}, {\"a\": -1.4270653467697816, \"b\": 5.089041275707647, \"c\": 4}, {\"a\": -6.67109445240842, \"b\": -8.381368795324502, \"c\": 2}, {\"a\": -10.132505632948824, \"b\": -2.904130256610637, \"c\": 2}, {\"a\": -11.178815676424925, \"b\": -4.413278651797786, \"c\": 2}, {\"a\": -10.057080406201601, \"b\": -2.5043591432049688, \"c\": 2}, {\"a\": -10.32899567358573, \"b\": -3.5668094022301133, \"c\": 2}, {\"a\": -4.090856931220461, \"b\": 0.7773894500089658, \"c\": 1}, {\"a\": -9.212485584018413, \"b\": -4.618216314330418, \"c\": 2}, {\"a\": -1.0377564016429472, \"b\": 3.806685337772314, \"c\": 4}, {\"a\": -3.030605723619092, \"b\": 1.095027222847604, \"c\": 1}, {\"a\": -0.03190915279961315, \"b\": 4.744501565417638, \"c\": 4}, {\"a\": -6.385581038708076, \"b\": -6.7256811532967005, \"c\": 2}, {\"a\": -0.6572399207287134, \"b\": 0.6903211669740015, \"c\": 0}, {\"a\": -2.3609043322056964, \"b\": 3.8692668449678234, \"c\": 4}, {\"a\": -1.1672233500118707, \"b\": 3.7258117278342757, \"c\": 4}, {\"a\": -5.912283048647135, \"b\": -8.377463876747543, \"c\": 2}, {\"a\": -2.207240807216247, \"b\": 1.0422648244353905, \"c\": 1}, {\"a\": -1.7824501314671677, \"b\": 3.4707204345840927, \"c\": 4}, {\"a\": -0.7587039566841077, \"b\": 3.7227620096688283, \"c\": 4}, {\"a\": -9.05271171505236, \"b\": -7.291939589232594, \"c\": 2}, {\"a\": -5.9745420961263935, \"b\": -3.51838113303937, \"c\": 2}, {\"a\": -11.717106978272625, \"b\": -3.8962275512811124, \"c\": 2}, {\"a\": -9.407673039492272, \"b\": -4.632732330360439, \"c\": 2}, {\"a\": -1.5394009534668904, \"b\": 5.023692978550581, \"c\": 4}, {\"a\": -7.185771494144075, \"b\": -8.413788695246396, \"c\": 2}, {\"a\": -4.2637085063554006, \"b\": 1.7064916774588386, \"c\": 1}, {\"a\": -10.52994652455128, \"b\": -2.835215150645509, \"c\": 2}, {\"a\": -1.3788948288258804, \"b\": 4.333377165095884, \"c\": 4}, {\"a\": -9.388928844744992, \"b\": -5.834759414529264, \"c\": 2}, {\"a\": -5.685002282586792, \"b\": -8.310070715138814, \"c\": 2}, {\"a\": -9.626042212441236, \"b\": -2.1003390622938256, \"c\": 2}, {\"a\": -1.1466300855305107, \"b\": 4.108397033740446, \"c\": 4}, {\"a\": -5.9371308387075095, \"b\": -8.102934865596996, \"c\": 2}, {\"a\": -5.955823946726122, \"b\": -2.823917833353274, \"c\": 2}, {\"a\": -1.242257900973657, \"b\": 5.191260519858751, \"c\": 4}, {\"a\": -7.811824639386145, \"b\": -2.584879239949342, \"c\": 2}, {\"a\": -9.31990493253329, \"b\": -5.05992161475509, \"c\": 2}, {\"a\": -1.4172753995351952, \"b\": 2.163160274008183, \"c\": 3}, {\"a\": -10.137064309104023, \"b\": -4.6818860367879065, \"c\": 2}, {\"a\": -6.465668948198481, \"b\": -9.623465193645359, \"c\": 2}, {\"a\": -6.677147520914788, \"b\": -8.508026866634719, \"c\": 2}, {\"a\": -7.264821576879018, \"b\": -8.145839120917861, \"c\": 2}, {\"a\": -6.004554674500931, \"b\": -9.864395764248538, \"c\": 2}, {\"a\": -5.971206013377806, \"b\": -3.8895724987058116, \"c\": 2}, {\"a\": -4.45264490609506, \"b\": 6.344018682459241, \"c\": 4}, {\"a\": -2.3857984954398956, \"b\": 0.8093985857965992, \"c\": 1}, {\"a\": -4.745547909045148, \"b\": -2.402302819007399, \"c\": 2}, {\"a\": -2.8923344726596043, \"b\": 1.7402392775090976, \"c\": 1}, {\"a\": -5.911217886456138, \"b\": -3.954988139839987, \"c\": 2}, {\"a\": -1.3439249587069142, \"b\": 2.3842886530191585, \"c\": 3}, {\"a\": -1.7800244777370269, \"b\": 3.1733691333967347, \"c\": 3}, {\"a\": -5.608354797184962, \"b\": -7.836590868920087, \"c\": 2}, {\"a\": -9.305138156113745, \"b\": -4.4320209037788665, \"c\": 2}, {\"a\": -5.141066757686813, \"b\": -8.759209425162643, \"c\": 2}, {\"a\": -3.31028117177262, \"b\": 3.515934284680113, \"c\": 4}, {\"a\": -7.101163472211441, \"b\": -8.985623452312733, \"c\": 2}, {\"a\": -1.0410207751622265, \"b\": 3.9633179381425236, \"c\": 4}, {\"a\": -10.273558566214245, \"b\": -2.7243929617125073, \"c\": 2}, {\"a\": -7.050690596418449, \"b\": -4.094382681095018, \"c\": 2}, {\"a\": -8.892085866834517, \"b\": -4.903512546706308, \"c\": 2}, {\"a\": -0.10075436532866022, \"b\": 4.515892565268589, \"c\": 4}, {\"a\": -6.623889469029814, \"b\": -2.8497407535085997, \"c\": 2}, {\"a\": -7.2181183454248306, \"b\": -10.585736617271158, \"c\": 2}, {\"a\": -3.1371758173775595, \"b\": 1.0663760444226433, \"c\": 1}, {\"a\": -5.705891681943866, \"b\": -1.1599851537849273, \"c\": 1}, {\"a\": -3.0861153264690513, \"b\": 6.174449817154188, \"c\": 4}, {\"a\": -1.041574372028185, \"b\": 4.222313543189416, \"c\": 4}, {\"a\": -10.488837641443919, \"b\": -3.8189754313234503, \"c\": 2}, {\"a\": -0.9170438407798296, \"b\": 0.26159975799881774, \"c\": 0}, {\"a\": -3.3337557135674514, \"b\": 5.231519693282148, \"c\": 4}, {\"a\": -6.6378492232412745, \"b\": -4.520852485287953, \"c\": 2}, {\"a\": -9.372920697286037, \"b\": -7.826159697054678, \"c\": 2}, {\"a\": -3.328031456453049, \"b\": -0.5479145371131793, \"c\": 1}, {\"a\": -2.1577734695795976, \"b\": 4.095504890540311, \"c\": 4}, {\"a\": -7.2479441706197125, \"b\": -8.37425700641238, \"c\": 2}, {\"a\": -8.574098074304114, \"b\": -3.0493493733596777, \"c\": 2}, {\"a\": -7.381783380186085, \"b\": -7.512242238240539, \"c\": 2}, {\"a\": -7.32608410311425, \"b\": -7.28996470568663, \"c\": 2}, {\"a\": -7.511581387134859, \"b\": -7.9488507097028815, \"c\": 2}, {\"a\": -7.101260827421833, \"b\": -6.252448784900219, \"c\": 2}, {\"a\": -5.3208035422282345, \"b\": -3.8519280602217214, \"c\": 2}, {\"a\": -10.029529676351892, \"b\": -3.840860804949009, \"c\": 2}, {\"a\": -9.869335513497157, \"b\": -2.1929333637878825, \"c\": 2}, {\"a\": -5.51746764814952, \"b\": -3.1616777043509208, \"c\": 2}, {\"a\": -10.46386736047903, \"b\": -2.568357203714566, \"c\": 2}, {\"a\": -12.69607424531915, \"b\": -5.16668667319191, \"c\": 2}, {\"a\": -1.6982554152145706, \"b\": 2.7907175141398666, \"c\": 3}, {\"a\": -2.841878032458153, \"b\": 3.740735350644035, \"c\": 4}, {\"a\": -7.733777731433561, \"b\": -2.1362376407075496, \"c\": 2}, {\"a\": -1.3491137303298828, \"b\": 2.4072409341475134, \"c\": 3}, {\"a\": -1.8994399288573471, \"b\": 1.7526309781484064, \"c\": 3}, {\"a\": -1.4686444212810534, \"b\": 6.506745005322004, \"c\": 4}, {\"a\": -5.2790918310360775, \"b\": -3.7172480118938354, \"c\": 2}, {\"a\": -6.440815642141247, \"b\": -1.9198590848111732, \"c\": 2}, {\"a\": -11.345477444906765, \"b\": -2.4826086906718356, \"c\": 2}, {\"a\": -8.013321840111535, \"b\": -8.57670640184958, \"c\": 2}, {\"a\": -2.3308060367853387, \"b\": 4.39382526992426, \"c\": 4}, {\"a\": -1.2560682641577197, \"b\": 5.0000683920802285, \"c\": 4}, {\"a\": -7.848869197580316, \"b\": -2.988192041459319, \"c\": 2}, {\"a\": -1.225116292600387, \"b\": 0.12071799292079277, \"c\": 0}, {\"a\": -10.341613212863495, \"b\": -4.95351773723572, \"c\": 2}, {\"a\": -1.1687290342156478, \"b\": -0.3304441898143149, \"c\": 0}, {\"a\": -10.140908248660338, \"b\": -2.9203647684134535, \"c\": 2}, {\"a\": -4.557707039390259, \"b\": -3.8930624518622583, \"c\": 2}, {\"a\": -2.280805664786133, \"b\": 1.6100134929296641, \"c\": 1}, {\"a\": -1.0570835299884753, \"b\": 0.7359494721835231, \"c\": 0}, {\"a\": -7.435238966316019, \"b\": -1.5656887452110602, \"c\": 2}, {\"a\": -4.499429402940959, \"b\": -8.61734301027225, \"c\": 2}, {\"a\": -8.078739397762485, \"b\": -2.819086612329274, \"c\": 2}, {\"a\": -2.7544717516895614, \"b\": 4.575872301901829, \"c\": 4}, {\"a\": -7.028684720897304, \"b\": -6.123230617183584, \"c\": 2}, {\"a\": -2.346732606068119, \"b\": 3.561284227344442, \"c\": 4}, {\"a\": -7.10087236538493, \"b\": -7.1161891228501375, \"c\": 2}, {\"a\": -10.803890715606558, \"b\": -3.9042868549901018, \"c\": 2}, {\"a\": -11.785625394852817, \"b\": -3.5915012315236363, \"c\": 2}, {\"a\": -2.482521133168507, \"b\": -0.12054490634897896, \"c\": 1}, {\"a\": -0.8645338115236748, \"b\": 4.032051549999941, \"c\": 4}, {\"a\": -5.556579389884729, \"b\": -3.8349591697963916, \"c\": 2}, {\"a\": -0.25247342379158444, \"b\": 0.25884485760516396, \"c\": 0}, {\"a\": -8.110416431034633, \"b\": -7.797943597617816, \"c\": 2}, {\"a\": -2.255679686786209, \"b\": -0.009786590173028742, \"c\": 1}, {\"a\": -3.027313079766596, \"b\": -0.4756227523401879, \"c\": 1}, {\"a\": -7.110845252498967, \"b\": -2.9811905209705296, \"c\": 2}, {\"a\": -7.775537954338522, \"b\": -7.022099504199083, \"c\": 2}, {\"a\": -2.3557826861809397, \"b\": 1.384049928539428, \"c\": 1}, {\"a\": -9.546589564918502, \"b\": -4.648269448548444, \"c\": 2}, {\"a\": -3.2336118601858344, \"b\": -1.1231284195543116, \"c\": 1}, {\"a\": -0.9802319519537215, \"b\": 0.6662377217484773, \"c\": 0}, {\"a\": -6.58403607039257, \"b\": -8.04390974071861, \"c\": 2}, {\"a\": -5.109460331307375, \"b\": -2.89214016417214, \"c\": 2}, {\"a\": 0.4062234142703147, \"b\": 2.9353329430105366, \"c\": 3}, {\"a\": -5.309907635576956, \"b\": -0.6644788398745298, \"c\": 1}, {\"a\": -4.830160446031853, \"b\": -8.106381899765744, \"c\": 2}, {\"a\": -4.829350464433686, \"b\": -5.709797094947043, \"c\": 2}, {\"a\": -1.415676909366551, \"b\": 0.19049093269352402, \"c\": 1}, {\"a\": -9.486774729161013, \"b\": -2.2426867086920694, \"c\": 2}, {\"a\": -0.5427847487191042, \"b\": 0.9787820369811178, \"c\": 0}, {\"a\": -0.6387084878890505, \"b\": 2.234673016819632, \"c\": 3}, {\"a\": -6.774094237189033, \"b\": -8.591282612111668, \"c\": 2}, {\"a\": -4.674736221324228, \"b\": -7.907805255434925, \"c\": 2}, {\"a\": -5.608205853417994, \"b\": -4.624537667930936, \"c\": 2}, {\"a\": -5.606916211082247, \"b\": -3.1190822385778567, \"c\": 2}, {\"a\": -6.7091649220817215, \"b\": -7.303641259529223, \"c\": 2}, {\"a\": -6.491919457700982, \"b\": -7.695281028314303, \"c\": 2}, {\"a\": -1.3142757038941042, \"b\": 0.6937394411054633, \"c\": 1}, {\"a\": -10.598869304302484, \"b\": -3.3972750372858194, \"c\": 2}, {\"a\": -9.349068859562434, \"b\": -3.846005253539615, \"c\": 2}, {\"a\": -5.3710863392286265, \"b\": -3.6529493896844274, \"c\": 2}, {\"a\": -1.6949278308272304, \"b\": 6.517094922443871, \"c\": 4}, {\"a\": 0.47826816149096274, \"b\": 3.6209558719229262, \"c\": 3}, {\"a\": -4.166000558624581, \"b\": 2.2923259469263355, \"c\": 1}, {\"a\": -5.676908374108773, \"b\": -7.9270283477808885, \"c\": 2}, {\"a\": -3.1901032616368, \"b\": 0.43376373775476007, \"c\": 1}, {\"a\": -3.1346674195157114, \"b\": 1.390286244146961, \"c\": 1}, {\"a\": -1.0361977293704867, \"b\": 3.971533185887934, \"c\": 4}, {\"a\": -5.773693280806863, \"b\": -8.26967225289571, \"c\": 2}, {\"a\": -7.894893169225412, \"b\": -9.172747954029761, \"c\": 2}, {\"a\": -6.49575758783296, \"b\": -7.955912112876255, \"c\": 2}, {\"a\": -1.349317066281828, \"b\": 1.2154620532859408, \"c\": 3}, {\"a\": -10.256695357053633, \"b\": -3.764055349804547, \"c\": 2}, {\"a\": -6.460687950068828, \"b\": -2.5393636321588664, \"c\": 2}, {\"a\": -2.4954202547788698, \"b\": 1.720619409266428, \"c\": 1}, {\"a\": -9.043216837105414, \"b\": -3.85760177625307, \"c\": 2}, {\"a\": -1.5533371819133017, \"b\": 2.880809552613804, \"c\": 3}, {\"a\": -6.907385914836152, \"b\": -3.298632407665963, \"c\": 2}, {\"a\": -0.9985396183498266, \"b\": 6.198648077818729, \"c\": 4}, {\"a\": -10.249386711284526, \"b\": -3.5706333736388407, \"c\": 2}, {\"a\": -1.9386576274918097, \"b\": 6.029338954797162, \"c\": 4}, {\"a\": -1.8482162510373346, \"b\": -0.047109224126220095, \"c\": 1}, {\"a\": -8.42583892765054, \"b\": -2.9524844537687724, \"c\": 2}, {\"a\": -8.026145782688248, \"b\": -9.611552565017199, \"c\": 2}, {\"a\": -4.635834169292622, \"b\": -4.41427672483403, \"c\": 2}, {\"a\": -6.855785507082218, \"b\": -6.598212110290956, \"c\": 2}, {\"a\": -3.465244962055252, \"b\": 2.3259435332784015, \"c\": 1}, {\"a\": -4.124441964853688, \"b\": -2.1469192838969193, \"c\": 1}, {\"a\": -6.575726488645982, \"b\": -2.837475827052767, \"c\": 2}, {\"a\": -1.4741566491862959, \"b\": 1.8537112476935205, \"c\": 3}, {\"a\": -7.585450338071976, \"b\": -3.5894870343265524, \"c\": 2}, {\"a\": -5.470417551835517, \"b\": -9.048669628573965, \"c\": 2}, {\"a\": -3.3726218590502883, \"b\": 2.2487309867957075, \"c\": 1}, {\"a\": -7.076616398034297, \"b\": -8.863728779291, \"c\": 2}, {\"a\": -5.616258900886787, \"b\": -2.0898838101457637, \"c\": 2}, {\"a\": -1.5032960556784363, \"b\": 4.2162688437583, \"c\": 4}, {\"a\": -6.619785473313167, \"b\": -8.055115858402054, \"c\": 2}, {\"a\": -1.9285460515011272, \"b\": 1.8492657780639326, \"c\": 3}, {\"a\": -8.957623350499006, \"b\": -4.87178858566323, \"c\": 2}, {\"a\": -6.917669367366214, \"b\": -2.253727093777896, \"c\": 2}, {\"a\": -2.444339470836848, \"b\": 0.4053031621723317, \"c\": 1}, {\"a\": -6.523101605633506, \"b\": -1.6862839328534043, \"c\": 2}, {\"a\": -6.9326344047379544, \"b\": -8.716464708741501, \"c\": 2}, {\"a\": -1.2181954623799376, \"b\": 4.3063346355596615, \"c\": 4}, {\"a\": -8.688006597970448, \"b\": -5.108331182292569, \"c\": 2}, {\"a\": -8.445506831523652, \"b\": -3.7042770985647997, \"c\": 2}, {\"a\": -6.309490154466883, \"b\": -7.4522459831008, \"c\": 2}, {\"a\": -1.9999331431990486, \"b\": 1.3333336202396378, \"c\": 1}, {\"a\": -5.3857564157444795, \"b\": -1.2639666725490577, \"c\": 1}, {\"a\": -9.361129094238471, \"b\": -2.5440951579991964, \"c\": 2}, {\"a\": -0.8576988740771748, \"b\": 4.453057167267307, \"c\": 4}, {\"a\": -2.205334073931087, \"b\": 4.207652005954265, \"c\": 4}, {\"a\": -9.67644658916927, \"b\": -4.678563473108571, \"c\": 2}, {\"a\": -2.5127623214801167, \"b\": 0.1655396772187261, \"c\": 1}, {\"a\": -7.105969175631985, \"b\": -3.6527719175492015, \"c\": 2}, {\"a\": -1.4729985149602352, \"b\": 4.816541516051418, \"c\": 4}, {\"a\": -10.286709846662918, \"b\": -4.345164787171253, \"c\": 2}, {\"a\": -9.183369374504176, \"b\": -3.1728786176048303, \"c\": 2}, {\"a\": -10.561501238235405, \"b\": -3.8636621400406144, \"c\": 2}, {\"a\": -7.635775546351138, \"b\": -3.4357954082506303, \"c\": 2}, {\"a\": -7.610491224145191, \"b\": -2.5028326726195385, \"c\": 2}, {\"a\": -2.480726059546784, \"b\": 1.4079917810580134, \"c\": 1}, {\"a\": -2.776029923833264, \"b\": 4.48741696981644, \"c\": 4}, {\"a\": -4.880714729946153, \"b\": -3.677565066307565, \"c\": 2}, {\"a\": -5.967464705399524, \"b\": -3.0207534244706324, \"c\": 2}, {\"a\": -6.7762654679809335, \"b\": -8.09492072187996, \"c\": 2}, {\"a\": -2.140701481541631, \"b\": 0.44946860135159356, \"c\": 1}, {\"a\": -11.554654061518132, \"b\": -4.565790675647549, \"c\": 2}, {\"a\": -2.512123788116238, \"b\": 0.9649175924448453, \"c\": 1}, {\"a\": -0.8875802951663574, \"b\": 2.4163920477162106, \"c\": 3}, {\"a\": -7.251323454941623, \"b\": -8.508469618121007, \"c\": 2}, {\"a\": -0.8667530400291719, \"b\": 3.7829591391633697, \"c\": 4}, {\"a\": -1.9766144192617214, \"b\": 0.03457444856459968, \"c\": 1}, {\"a\": -2.406718199699357, \"b\": 6.098944469870908, \"c\": 4}, {\"a\": -7.726774018597411, \"b\": -7.894196202832041, \"c\": 2}, {\"a\": -0.04261030709121938, \"b\": 4.909230750843066, \"c\": 4}, {\"a\": -6.856988210572915, \"b\": -2.7619724800199896, \"c\": 2}, {\"a\": -3.127579277758952, \"b\": 0.5217016146015367, \"c\": 1}, {\"a\": -7.957528857170622, \"b\": -8.314426424165282, \"c\": 2}, {\"a\": -4.973570934717421, \"b\": -3.401177574330481, \"c\": 2}, {\"a\": -7.820544948759704, \"b\": -6.301790210050536, \"c\": 2}, {\"a\": -2.8020781039706595, \"b\": 4.057147146430284, \"c\": 4}, {\"a\": -11.094866863908464, \"b\": -3.1147138001348273, \"c\": 2}, {\"a\": -7.840352618361661, \"b\": -6.255717297484694, \"c\": 2}, {\"a\": -5.3181062828145205, \"b\": -3.1703554787907446, \"c\": 2}, {\"a\": -2.1017891854616924, \"b\": 4.7300172224445935, \"c\": 4}, {\"a\": -0.41605643833551675, \"b\": 1.2091248797016774, \"c\": 0}, {\"a\": -7.305582685409725, \"b\": -9.008899497018543, \"c\": 2}, {\"a\": -2.075176690807616, \"b\": 0.38809377307793236, \"c\": 1}, {\"a\": -2.060438097737446, \"b\": 5.230495487293569, \"c\": 4}, {\"a\": -10.501686452795418, \"b\": -3.9353926557123784, \"c\": 2}, {\"a\": -7.0504337686399525, \"b\": -9.632808139240158, \"c\": 2}, {\"a\": -8.773008486706246, \"b\": -2.704426106064386, \"c\": 2}, {\"a\": -6.285390317605527, \"b\": -9.239529011834936, \"c\": 2}, {\"a\": -2.196356077960892, \"b\": 2.9486674763225644, \"c\": 3}, {\"a\": -3.198353151693163, \"b\": 3.9585946841270427, \"c\": 4}, {\"a\": -7.3512670990529125, \"b\": -9.024115754276005, \"c\": 2}, {\"a\": -6.452649660529685, \"b\": -7.408343568183393, \"c\": 2}, {\"a\": -5.502462654164775, \"b\": -9.024029657232106, \"c\": 2}, {\"a\": -5.845007804627118, \"b\": -9.287020140017622, \"c\": 2}, {\"a\": -7.893029772846012, \"b\": -8.263956518665143, \"c\": 2}, {\"a\": -2.3599584108697744, \"b\": 4.203095419878603, \"c\": 4}, {\"a\": -6.277701222722124, \"b\": -3.149415761418287, \"c\": 2}, {\"a\": -4.778390461086368, \"b\": -1.4180562374281203, \"c\": 1}, {\"a\": -6.896003111237657, \"b\": -3.405024786771265, \"c\": 2}, {\"a\": -5.746845218114043, \"b\": -4.649905349797732, \"c\": 2}, {\"a\": -7.082699732711678, \"b\": -8.753366903859657, \"c\": 2}, {\"a\": -7.318195379350269, \"b\": -2.569816087730699, \"c\": 2}, {\"a\": -11.346408950450343, \"b\": -2.6508130108770245, \"c\": 2}, {\"a\": -8.772556654379871, \"b\": -5.00689462106352, \"c\": 2}, {\"a\": -3.682968446996577, \"b\": 2.637899782344628, \"c\": 1}, {\"a\": -9.547556990885923, \"b\": -2.188013446844133, \"c\": 2}, {\"a\": -2.616330759197613, \"b\": 0.4597030374816789, \"c\": 1}, {\"a\": -9.625255652141659, \"b\": -4.101838350422598, \"c\": 2}, {\"a\": -0.3858039757897429, \"b\": 6.373591618097896, \"c\": 4}, {\"a\": -4.737415964715585, \"b\": -1.5130020132768807, \"c\": 1}, {\"a\": -10.416650401331225, \"b\": -4.4325334624906105, \"c\": 2}, {\"a\": -5.554109837684413, \"b\": -4.634233096558838, \"c\": 2}, {\"a\": -4.063414459559936, \"b\": 0.9893604064619951, \"c\": 1}, {\"a\": -6.383903256343688, \"b\": -6.390619203207397, \"c\": 2}, {\"a\": -10.422205294224028, \"b\": -4.684879529093538, \"c\": 2}, {\"a\": -10.22012653218301, \"b\": -2.4831882035374644, \"c\": 2}, {\"a\": -1.340520809891421, \"b\": 4.157119493365752, \"c\": 4}, {\"a\": -0.5451769291687276, \"b\": 3.819965930021569, \"c\": 4}, {\"a\": -4.856094553308434, \"b\": 2.78189625595512, \"c\": 1}, {\"a\": -5.685123992051522, \"b\": -7.550777203384435, \"c\": 2}, {\"a\": -6.88971445443967, \"b\": -8.206711797359201, \"c\": 2}, {\"a\": -9.188868143387419, \"b\": -2.163593864156933, \"c\": 2}, {\"a\": -2.5177554667645348, \"b\": 0.03537133746078014, \"c\": 1}, {\"a\": -3.176964805593009, \"b\": 1.5074800496257021, \"c\": 1}, {\"a\": -1.8975018417007021, \"b\": 5.561777754931387, \"c\": 4}, {\"a\": -10.476869602439182, \"b\": -3.6031813885349258, \"c\": 2}, {\"a\": -1.038477205109511, \"b\": 5.362611572967858, \"c\": 4}, {\"a\": -6.059195503346523, \"b\": -7.799660888621416, \"c\": 2}, {\"a\": -6.1336265048896195, \"b\": -7.203419289412715, \"c\": 2}, {\"a\": -1.631290163282112, \"b\": 0.5463786574212511, \"c\": 1}, {\"a\": -6.969886073588578, \"b\": -8.072477116001025, \"c\": 2}, {\"a\": -9.304346277992718, \"b\": -4.711415875919437, \"c\": 2}, {\"a\": -5.261293202171242, \"b\": -8.605753077908071, \"c\": 2}, {\"a\": -2.8747905460303103, \"b\": 1.3909972661924948, \"c\": 1}, {\"a\": -1.643032338642904, \"b\": 4.583677589119122, \"c\": 4}, {\"a\": -4.100552950393592, \"b\": 0.11542620400706571, \"c\": 1}, {\"a\": -2.5934745615750208, \"b\": 3.8734695427595622, \"c\": 4}, {\"a\": -9.25435596013924, \"b\": -5.462921231587248, \"c\": 2}, {\"a\": -6.9043171919152275, \"b\": -8.273378080252794, \"c\": 2}, {\"a\": -6.605100483447555, \"b\": -8.359559016668925, \"c\": 2}, {\"a\": -2.0108681109595214, \"b\": 0.31675284689477085, \"c\": 1}, {\"a\": -6.196103722605896, \"b\": -4.282154149501972, \"c\": 2}, {\"a\": -6.135916897910412, \"b\": -4.292886808808747, \"c\": 2}, {\"a\": -7.634030837169709, \"b\": -9.215024865934893, \"c\": 2}, {\"a\": -0.8486082331449638, \"b\": 5.4509319635504205, \"c\": 4}, {\"a\": -1.2973568888991842, \"b\": -0.7043199392131283, \"c\": 0}, {\"a\": -10.855209328392874, \"b\": -4.887530390511154, \"c\": 2}, {\"a\": -0.21641714741869977, \"b\": 1.6984450482077, \"c\": 3}, {\"a\": -8.376800218031354, \"b\": -4.759533364745429, \"c\": 2}, {\"a\": -1.6158909127701304, \"b\": 4.180175626329556, \"c\": 4}, {\"a\": 0.31975462308127556, \"b\": 0.7018372646939518, \"c\": 0}, {\"a\": -7.272416614284635, \"b\": -4.228485547171829, \"c\": 2}, {\"a\": -9.925460604497216, \"b\": -2.943561212415646, \"c\": 2}, {\"a\": -6.924772302352986, \"b\": -9.572376881768532, \"c\": 2}, {\"a\": -4.0945955845718895, \"b\": 1.384281266156274, \"c\": 1}, {\"a\": -10.849168160183929, \"b\": -2.9524671236829034, \"c\": 2}, {\"a\": -3.167620064310973, \"b\": 1.535828273062233, \"c\": 1}, {\"a\": -9.18166881932904, \"b\": -4.565755520492028, \"c\": 2}, {\"a\": -2.7632211774364555, \"b\": -1.5527064423598667, \"c\": 1}, {\"a\": -10.279448772718714, \"b\": -1.8969930241649111, \"c\": 2}, {\"a\": -3.0260143179480554, \"b\": -0.650680948644488, \"c\": 1}, {\"a\": -3.1796180195821035, \"b\": -0.5256243459488241, \"c\": 1}, {\"a\": -9.54642848761293, \"b\": -5.637408533231442, \"c\": 2}, {\"a\": -6.5504706230914165, \"b\": -8.170478969883762, \"c\": 2}, {\"a\": -1.3830606011263358, \"b\": 3.673218264947849, \"c\": 4}, {\"a\": -1.8277587456932356, \"b\": 4.232309524535171, \"c\": 4}, {\"a\": -1.230033765926555, \"b\": 3.7994914706431153, \"c\": 4}, {\"a\": -6.6792798913134135, \"b\": -7.4349373688697025, \"c\": 2}, {\"a\": -3.1013063829484038, \"b\": 1.3215622710519839, \"c\": 1}, {\"a\": -2.537526074416154, \"b\": -0.6307294304303832, \"c\": 1}, {\"a\": 0.06990104352606297, \"b\": 0.749370290784109, \"c\": 0}, {\"a\": -9.272161985574368, \"b\": -4.277552766848416, \"c\": 2}, {\"a\": -11.949817790898333, \"b\": -5.355677692816341, \"c\": 2}, {\"a\": -6.1942354018444945, \"b\": -2.171365692736804, \"c\": 2}, {\"a\": -6.594076631194901, \"b\": -3.2774517980441633, \"c\": 2}, {\"a\": -5.43294633500271, \"b\": -8.555016938455932, \"c\": 2}, {\"a\": -8.095680211416521, \"b\": -8.425166904308595, \"c\": 2}, {\"a\": -7.699286893958584, \"b\": -8.678331498562985, \"c\": 2}, {\"a\": -5.4591954127357045, \"b\": -3.370791361550005, \"c\": 2}, {\"a\": -3.5175417703952716, \"b\": 5.642653899295982, \"c\": 4}, {\"a\": -6.546024487566844, \"b\": -1.225872369365573, \"c\": 2}, {\"a\": -0.5714277147325475, \"b\": -0.15230959531221355, \"c\": 0}, {\"a\": -8.251277414425129, \"b\": -4.728418834436639, \"c\": 2}, {\"a\": -2.8221015487897603, \"b\": 0.4136887612997143, \"c\": 1}, {\"a\": -1.611936893150238, \"b\": 2.3298999016292457, \"c\": 3}, {\"a\": -5.76754418790721, \"b\": -3.2053528831957903, \"c\": 2}, {\"a\": -5.468882465107992, \"b\": -3.30833762623321, \"c\": 2}, {\"a\": -7.390943489417875, \"b\": -8.18413952222818, \"c\": 2}, {\"a\": -5.742188198549099, \"b\": -7.9590530883302675, \"c\": 2}, {\"a\": -3.028307100287639, \"b\": 1.1495956537175838, \"c\": 1}, {\"a\": -3.5229864547505656, \"b\": 1.727716492547085, \"c\": 1}, {\"a\": -8.536820123190024, \"b\": -3.3608757459391847, \"c\": 2}, {\"a\": -10.453830058801787, \"b\": -4.9332387990250055, \"c\": 2}, {\"a\": -7.122248310296294, \"b\": -2.3038808117516716, \"c\": 2}, {\"a\": -7.070422385235707, \"b\": -3.798838008132097, \"c\": 2}, {\"a\": -2.4376707077016575, \"b\": -0.5559706134492894, \"c\": 1}, {\"a\": -2.059882683610289, \"b\": 1.3305872199759001, \"c\": 1}, {\"a\": -2.8519640573549134, \"b\": 1.0232574112058959, \"c\": 1}, {\"a\": -7.116365110423072, \"b\": -6.242142909330093, \"c\": 2}, {\"a\": -5.591439517867313, \"b\": -2.4802054090113486, \"c\": 2}, {\"a\": -10.15470617614642, \"b\": -5.288551270378396, \"c\": 2}, {\"a\": -8.97916002888522, \"b\": -2.72279034740848, \"c\": 2}, {\"a\": -8.836272521978708, \"b\": -3.9808779336311826, \"c\": 2}, {\"a\": -5.115785133583627, \"b\": -4.24458573062658, \"c\": 2}, {\"a\": -6.918116920270849, \"b\": -7.581423225759055, \"c\": 2}, {\"a\": -7.756151140419901, \"b\": -7.010664184618824, \"c\": 2}, {\"a\": -1.8461388994599859, \"b\": 4.349665387957314, \"c\": 4}, {\"a\": -9.468832758067927, \"b\": -6.190435058475675, \"c\": 2}, {\"a\": -0.49922133595474993, \"b\": 4.775982585218885, \"c\": 4}, {\"a\": -9.111886704687194, \"b\": -3.763486897980109, \"c\": 2}, {\"a\": -6.972605672573312, \"b\": -3.66711117615883, \"c\": 2}, {\"a\": -3.4542007538571173, \"b\": 1.6106178853188964, \"c\": 1}, {\"a\": -2.4139578469451726, \"b\": 5.659358024076449, \"c\": 4}, {\"a\": -3.0326772261952755, \"b\": 4.721649260885453, \"c\": 4}, {\"a\": -2.474867334658267, \"b\": 0.32266755534413927, \"c\": 1}, {\"a\": -12.084103069109627, \"b\": -3.591546906792158, \"c\": 2}, {\"a\": -2.1082979386201424, \"b\": 3.734041830056565, \"c\": 4}, {\"a\": -11.563450654309007, \"b\": -2.939526080391499, \"c\": 2}, {\"a\": -6.139380968955353, \"b\": -8.610215962217582, \"c\": 2}, {\"a\": -5.2642220611490425, \"b\": -2.8815555131275445, \"c\": 2}, {\"a\": -1.9897744174979342, \"b\": -1.0106007237126429, \"c\": 1}, {\"a\": -6.125425814331695, \"b\": -2.5066980716557024, \"c\": 2}, {\"a\": -8.81428760538696, \"b\": -6.827305421135563, \"c\": 2}, {\"a\": -10.91350435272178, \"b\": -4.360600590383171, \"c\": 2}, {\"a\": -7.708826501398667, \"b\": -2.4618791531687485, \"c\": 2}, {\"a\": 0.1511928204613171, \"b\": 1.6028112371355738, \"c\": 3}, {\"a\": -2.6380112446437294, \"b\": 0.6590870029375799, \"c\": 1}, {\"a\": -6.5743211398481, \"b\": -9.548511129689372, \"c\": 2}, {\"a\": -0.9076880183283702, \"b\": 0.6034953081716659, \"c\": 0}, {\"a\": -0.19745196890354544, \"b\": 2.3463491593455075, \"c\": 3}, {\"a\": -0.49489500547440746, \"b\": 0.4085024787012521, \"c\": 0}, {\"a\": -1.0749132954710934, \"b\": 4.730764112291583, \"c\": 4}, {\"a\": -6.240729909892731, \"b\": -3.0804262963815616, \"c\": 2}, {\"a\": -1.1563750925131935, \"b\": 5.6997157513754235, \"c\": 4}, {\"a\": -2.48436838529944, \"b\": -0.44973528117257744, \"c\": 1}, {\"a\": -10.036890759862597, \"b\": -4.182102718583417, \"c\": 2}, {\"a\": -6.503244087134333, \"b\": -6.638477722141793, \"c\": 2}, {\"a\": -10.118646564084044, \"b\": -7.673375733470228, \"c\": 2}, {\"a\": -2.351220657673829, \"b\": 4.0097363419871845, \"c\": 4}, {\"a\": -8.554835575156792, \"b\": -4.493030109565697, \"c\": 2}, {\"a\": -9.679558303974412, \"b\": -3.9725801814608417, \"c\": 2}, {\"a\": -6.824376631510376, \"b\": -9.152654605982224, \"c\": 2}, {\"a\": -6.799239781143454, \"b\": -8.413694163489424, \"c\": 2}, {\"a\": -1.198395805971502, \"b\": 3.230507197401846, \"c\": 3}, {\"a\": -11.111148606626092, \"b\": -4.020758572310059, \"c\": 2}, {\"a\": -2.2900705977446796, \"b\": 0.4792472588432516, \"c\": 1}, {\"a\": -9.342180180318104, \"b\": -8.222852644079174, \"c\": 2}, {\"a\": -7.101699840174766, \"b\": -8.040859615831826, \"c\": 2}, {\"a\": -3.602883311616872, \"b\": 4.7589842332124945, \"c\": 4}, {\"a\": -8.288761834232984, \"b\": -7.594963886056408, \"c\": 2}, {\"a\": -6.431730839429407, \"b\": -1.991937311282903, \"c\": 2}, {\"a\": -6.601540323828339, \"b\": -0.26148566507939464, \"c\": 2}, {\"a\": -8.611398239406782, \"b\": -3.4052189626750113, \"c\": 2}, {\"a\": -11.576868789047566, \"b\": -4.78197652621961, \"c\": 2}, {\"a\": -1.292328092064655, \"b\": 5.639389061219399, \"c\": 4}, {\"a\": -2.5129736221091834, \"b\": 1.469023591701653, \"c\": 1}, {\"a\": -1.3090139272844121, \"b\": 3.09420645760573, \"c\": 3}, {\"a\": -11.896524562972395, \"b\": -5.070459239802317, \"c\": 2}, {\"a\": -10.788512457428268, \"b\": -2.729626335403095, \"c\": 2}, {\"a\": -6.147481136874494, \"b\": -3.159735134039903, \"c\": 2}, {\"a\": -9.980547777279012, \"b\": -4.382490825598298, \"c\": 2}, {\"a\": -9.962768914289361, \"b\": -2.499430965754387, \"c\": 2}, {\"a\": -2.47072141658209, \"b\": 0.08792713689854625, \"c\": 1}, {\"a\": -7.475951427700032, \"b\": -3.387880425900189, \"c\": 2}, {\"a\": -7.880429534862484, \"b\": -8.883154716911685, \"c\": 2}, {\"a\": -11.105425005937654, \"b\": -3.9710668652733467, \"c\": 2}, {\"a\": -5.966591638610184, \"b\": -1.9732960850442367, \"c\": 2}, {\"a\": -8.789256175101139, \"b\": -2.837646744578718, \"c\": 2}, {\"a\": -10.196710687456825, \"b\": -2.0868771722110795, \"c\": 2}, {\"a\": -10.226478332523264, \"b\": -2.339987172800089, \"c\": 2}, {\"a\": -0.5361477439265843, \"b\": 4.711756909087172, \"c\": 4}, {\"a\": -0.7578199296191532, \"b\": 1.093049671605813, \"c\": 0}, {\"a\": -6.935238963206736, \"b\": -3.905629884999235, \"c\": 2}, {\"a\": -11.088050836107916, \"b\": -2.253160400717679, \"c\": 2}, {\"a\": -10.457655334493788, \"b\": -3.3089948813328824, \"c\": 2}, {\"a\": -5.1178408878485575, \"b\": -2.548252297894433, \"c\": 2}, {\"a\": -7.658175124932747, \"b\": -2.3713568371019873, \"c\": 2}, {\"a\": -6.2130925461424225, \"b\": -6.51862560325463, \"c\": 2}, {\"a\": -2.8793043029275522, \"b\": 6.855858517904559, \"c\": 4}, {\"a\": -2.034844856038634, \"b\": 3.7677594613889394, \"c\": 4}, {\"a\": -2.8588279382837056, \"b\": 5.2698351863871835, \"c\": 4}, {\"a\": -7.929712125123326, \"b\": -7.544479022282343, \"c\": 2}, {\"a\": -8.102171353012723, \"b\": -9.077769316200092, \"c\": 2}, {\"a\": -7.603914763677776, \"b\": -7.50912811668111, \"c\": 2}, {\"a\": -6.676633747482737, \"b\": -4.5535738777405195, \"c\": 2}, {\"a\": -1.1300945815958103, \"b\": 4.544191078840548, \"c\": 4}, {\"a\": -4.9598549849285565, \"b\": -3.1070429943130917, \"c\": 2}, {\"a\": -1.5512855797734204, \"b\": 1.6408363835897002, \"c\": 3}, {\"a\": -10.593380384563392, \"b\": -4.262469866005067, \"c\": 2}, {\"a\": -5.889637190949685, \"b\": -7.033329101067906, \"c\": 2}, {\"a\": -6.641878974074463, \"b\": -8.287476669254364, \"c\": 2}, {\"a\": -7.444001794458577, \"b\": -6.355308738235934, \"c\": 2}, {\"a\": -9.33603142718712, \"b\": -2.9669963671511406, \"c\": 2}, {\"a\": -5.270702667845091, \"b\": -2.2157796218235135, \"c\": 2}, {\"a\": 0.24509880239246162, \"b\": 5.517546567403667, \"c\": 4}, {\"a\": -6.263359201291166, \"b\": -1.6578526612964077, \"c\": 2}, {\"a\": -8.964261700388864, \"b\": -4.099621821974559, \"c\": 2}, {\"a\": -5.956937893344326, \"b\": -3.5154527431774976, \"c\": 2}, {\"a\": -2.9963320775462376, \"b\": -0.29136766282721593, \"c\": 1}, {\"a\": -1.8818880485588787, \"b\": 4.205731799913164, \"c\": 4}, {\"a\": -0.5279305184970926, \"b\": 5.92630668526536, \"c\": 4}, {\"a\": -9.571792327150286, \"b\": -3.9042681502215744, \"c\": 2}, {\"a\": -1.9181184426215276, \"b\": 1.0281943833206424, \"c\": 1}, {\"a\": -7.987960140742068, \"b\": -8.28342331282572, \"c\": 2}, {\"a\": -6.646927688322704, \"b\": -2.173166573645811, \"c\": 2}, {\"a\": -9.709634336647952, \"b\": -2.455240363786171, \"c\": 2}, {\"a\": -5.6107162249192095, \"b\": -4.400109841148538, \"c\": 2}, {\"a\": -7.21538650930819, \"b\": -7.237728836561472, \"c\": 2}, {\"a\": -8.30390339036502, \"b\": -3.7564787681129133, \"c\": 2}, {\"a\": -5.0857850153881925, \"b\": -5.407213936826451, \"c\": 2}, {\"a\": -8.077920217225014, \"b\": -5.3450424234172385, \"c\": 2}, {\"a\": -0.8068558442232332, \"b\": 4.4418499658979185, \"c\": 4}, {\"a\": -5.855200534897023, \"b\": -3.1798641940662242, \"c\": 2}, {\"a\": -6.57054053267536, \"b\": -9.647421869898729, \"c\": 2}, {\"a\": -4.63868065028663, \"b\": -2.6617269219648656, \"c\": 2}, {\"a\": -8.779771602851755, \"b\": -5.894029511728098, \"c\": 2}, {\"a\": -2.7786753045082477, \"b\": 6.362568772546803, \"c\": 4}, {\"a\": -2.5096455181025177, \"b\": -0.43993634251500024, \"c\": 1}, {\"a\": 0.09580521147267573, \"b\": 2.7753266939642476, \"c\": 3}, {\"a\": -2.932118661194514, \"b\": 4.720037589306593, \"c\": 4}, {\"a\": -9.816673759295231, \"b\": -2.8461730964141423, \"c\": 2}, {\"a\": -0.757969185355724, \"b\": 4.908984207745029, \"c\": 4}, {\"a\": -0.22878096984667273, \"b\": 0.9636233742067956, \"c\": 0}, {\"a\": -1.6173461592329268, \"b\": 4.9893050825589835, \"c\": 4}, {\"a\": -1.4612601858217498, \"b\": 4.525498514650621, \"c\": 4}, {\"a\": -6.540131691360915, \"b\": -8.630352311093377, \"c\": 2}, {\"a\": -11.070676782364746, \"b\": -3.458189936162888, \"c\": 2}, {\"a\": -6.953544917274769, \"b\": -8.172750662944319, \"c\": 2}, {\"a\": -7.372878917867614, \"b\": -2.3301483961175964, \"c\": 2}, {\"a\": -1.1643485819705592, \"b\": 4.2317867091006605, \"c\": 4}, {\"a\": -8.898716170905923, \"b\": -4.854983037839203, \"c\": 2}, {\"a\": -0.43137430580756386, \"b\": 1.0350771743794034, \"c\": 0}, {\"a\": -4.983802400818093, \"b\": -3.0089458478827584, \"c\": 2}, {\"a\": -9.547494761615257, \"b\": -3.325911464610094, \"c\": 2}, {\"a\": -8.237463277204007, \"b\": -4.014001039138014, \"c\": 2}, {\"a\": -1.0761398731674612, \"b\": 1.8177743144442817, \"c\": 3}, {\"a\": -5.498195982561595, \"b\": -8.390976202769409, \"c\": 2}, {\"a\": -0.3003654565740428, \"b\": -0.6111432544277957, \"c\": 0}, {\"a\": -9.48229870186986, \"b\": -5.068219599729142, \"c\": 2}, {\"a\": -1.6087521511724905, \"b\": 3.769494222273808, \"c\": 4}, {\"a\": -10.896395696971748, \"b\": -3.633691605418611, \"c\": 2}, {\"a\": -6.437705148266213, \"b\": -7.990419854317253, \"c\": 2}, {\"a\": -7.0524341298225295, \"b\": -2.3045122920319603, \"c\": 2}, {\"a\": -7.25543048131919, \"b\": -7.9198889783639235, \"c\": 2}, {\"a\": -5.1957387174958525, \"b\": -3.775617084917434, \"c\": 2}, {\"a\": -1.1909762927195962, \"b\": 1.709587976653136, \"c\": 3}, {\"a\": -5.797493376054698, \"b\": -3.3288550258918357, \"c\": 2}, {\"a\": -7.945071248199318, \"b\": -8.17222862617136, \"c\": 2}, {\"a\": -5.778290734088303, \"b\": -3.012808168716323, \"c\": 2}, {\"a\": -10.17732479830446, \"b\": -3.4516234380180393, \"c\": 2}, {\"a\": -2.004547116103499, \"b\": 4.175650125707692, \"c\": 4}, {\"a\": -2.071199069137002, \"b\": 5.685017951684883, \"c\": 4}, {\"a\": -9.855461131126784, \"b\": -3.439843067374657, \"c\": 2}, {\"a\": 0.5260155005846419, \"b\": 3.009993533355024, \"c\": 3}, {\"a\": -1.7331237848858934, \"b\": -0.2654356019541495, \"c\": 1}, {\"a\": -8.34430833997126, \"b\": -9.493437280527546, \"c\": 2}, {\"a\": -2.082416867339295, \"b\": 4.492954275367449, \"c\": 4}, {\"a\": -11.078423196098608, \"b\": -3.227874542881669, \"c\": 2}, {\"a\": -3.441533556392473, \"b\": 0.35977562019323767, \"c\": 1}, {\"a\": -0.5381421977128555, \"b\": 4.815390406779989, \"c\": 4}, {\"a\": -5.8020027687618425, \"b\": -2.0345784235032776, \"c\": 2}, {\"a\": -6.710280131544911, \"b\": -8.365601390114666, \"c\": 2}, {\"a\": -7.2916423758273226, \"b\": -9.717735958435242, \"c\": 2}, {\"a\": -7.412100183720695, \"b\": -3.891858125292522, \"c\": 2}, {\"a\": -4.874177886641892, \"b\": -4.588962342633836, \"c\": 2}, {\"a\": -8.575958791567942, \"b\": -9.024650170219003, \"c\": 2}, {\"a\": -3.3537805548615216, \"b\": 0.8861176261794901, \"c\": 1}, {\"a\": -8.889095745663425, \"b\": -4.656268950273374, \"c\": 2}, {\"a\": -9.12674270112086, \"b\": -4.461805681638605, \"c\": 2}, {\"a\": -8.42224459508072, \"b\": -2.7467406493276365, \"c\": 2}, {\"a\": -0.23474427733944436, \"b\": -0.6488214921952409, \"c\": 0}, {\"a\": -6.088584073976978, \"b\": -2.230499458256837, \"c\": 2}, {\"a\": -5.941681221975084, \"b\": -5.121325247960632, \"c\": 2}, {\"a\": -0.8133992583634861, \"b\": 3.546973928011175, \"c\": 4}, {\"a\": -2.5208762667245614, \"b\": 5.081201394531134, \"c\": 4}, {\"a\": -1.9274479855745354, \"b\": 4.9368453355813475, \"c\": 4}, {\"a\": -2.691107061716651, \"b\": -0.5421878313374087, \"c\": 1}, {\"a\": -5.3107731402291645, \"b\": -2.647829458458601, \"c\": 2}, {\"a\": -7.955470245217894, \"b\": -4.900539173858183, \"c\": 2}, {\"a\": -2.2882254028418214, \"b\": -0.29504520031956183, \"c\": 1}, {\"a\": -2.7606781866827563, \"b\": 2.7134662606914492, \"c\": 3}, {\"a\": -11.635162096661443, \"b\": 0.005254156674758814, \"c\": 2}, {\"a\": -0.8235551865142507, \"b\": 5.949848979647645, \"c\": 4}, {\"a\": -1.8534168542265617, \"b\": 2.823989517210697, \"c\": 3}, {\"a\": -9.579806808063516, \"b\": -7.338603089639757, \"c\": 2}, {\"a\": -2.872372882081665, \"b\": 2.0097595893664018, \"c\": 1}, {\"a\": -1.431141644608008, \"b\": -0.9159678687832462, \"c\": 1}, {\"a\": -2.08700988740945, \"b\": -0.6241352970572613, \"c\": 1}, {\"a\": -8.928740881451839, \"b\": -3.9129771163403655, \"c\": 2}, {\"a\": -2.8896180416154813, \"b\": 4.957027364819377, \"c\": 4}, {\"a\": -8.609277965044438, \"b\": -9.699789144592701, \"c\": 2}, {\"a\": -5.286217688037984, \"b\": -3.331611880613228, \"c\": 2}, {\"a\": -1.499522836500689, \"b\": 5.282658789959386, \"c\": 4}, {\"a\": -1.5255117093938964, \"b\": 5.608544731042867, \"c\": 4}, {\"a\": -9.54609655309786, \"b\": -2.8491742210599913, \"c\": 2}, {\"a\": -3.154185520488078, \"b\": 1.3154729021376994, \"c\": 1}, {\"a\": -1.359389585992692, \"b\": 4.054240022349643, \"c\": 4}, {\"a\": -5.903596490315931, \"b\": -7.083262565673912, \"c\": 2}, {\"a\": -10.924584442861725, \"b\": -4.135768953726302, \"c\": 2}, {\"a\": -6.224873284378726, \"b\": -2.869307965363608, \"c\": 2}, {\"a\": -6.666283795496302, \"b\": -8.345231801255089, \"c\": 2}, {\"a\": -6.670454153645626, \"b\": -7.427705546370486, \"c\": 2}, {\"a\": -10.103057216160643, \"b\": -3.323152876678294, \"c\": 2}, {\"a\": -5.622616136631554, \"b\": -3.3202702895098737, \"c\": 2}, {\"a\": -6.129734404066664, \"b\": -6.340700289506504, \"c\": 2}, {\"a\": -0.8079130445052689, \"b\": 1.5154285163097623, \"c\": 3}, {\"a\": -10.94977460435936, \"b\": -4.471494099761959, \"c\": 2}, {\"a\": -1.192071525654876, \"b\": 1.0864372761988392, \"c\": 0}, {\"a\": -6.711011756774898, \"b\": -8.340183121156794, \"c\": 2}, {\"a\": -11.193574013977583, \"b\": -1.4473682620445318, \"c\": 2}, {\"a\": -8.691506438517653, \"b\": -4.557951516527581, \"c\": 2}, {\"a\": -1.4294651705841361, \"b\": 5.168501049155187, \"c\": 4}, {\"a\": -7.154525574058807, \"b\": -0.9355519898760924, \"c\": 2}, {\"a\": -0.7341444001917445, \"b\": 0.7662449117106108, \"c\": 0}, {\"a\": -6.559828431365641, \"b\": -8.420232283965959, \"c\": 2}, {\"a\": -9.82784324830553, \"b\": -5.1173565185244065, \"c\": 2}, {\"a\": -8.704162882989793, \"b\": -4.392346211029482, \"c\": 2}, {\"a\": -10.04357918972287, \"b\": -4.172082006330914, \"c\": 2}, {\"a\": -6.960828793948649, \"b\": -7.625224682552209, \"c\": 2}, {\"a\": -2.7004972139703103, \"b\": 1.0278081245383408, \"c\": 1}, {\"a\": -7.543654731620382, \"b\": -1.3300261090552106, \"c\": 2}, {\"a\": -6.012920293506242, \"b\": -3.6758144642938486, \"c\": 2}, {\"a\": -1.7960046498445525, \"b\": 4.287435681068351, \"c\": 4}, {\"a\": -2.436715196396561, \"b\": 0.8606320709774297, \"c\": 1}, {\"a\": 0.8687658008578785, \"b\": 4.1578550911277015, \"c\": 4}, {\"a\": -8.047043141686407, \"b\": -8.600536266377423, \"c\": 2}, {\"a\": -9.660491565344643, \"b\": -2.9452831142874416, \"c\": 2}, {\"a\": -1.9257784119521415, \"b\": 4.43910441553652, \"c\": 4}, {\"a\": -7.177627514950364, \"b\": -2.507276175897589, \"c\": 2}, {\"a\": -5.475554901311062, \"b\": -1.7572529355601165, \"c\": 2}, {\"a\": -9.220293298404238, \"b\": -4.0721197194662935, \"c\": 2}, {\"a\": -3.2457134131243985, \"b\": 1.514388365426442, \"c\": 1}, {\"a\": -2.637252332697235, \"b\": -0.8734156239475332, \"c\": 1}, {\"a\": -9.03149164107476, \"b\": -3.2274316948423833, \"c\": 2}, {\"a\": -1.0572406256528906, \"b\": 4.826772072490221, \"c\": 4}, {\"a\": -6.789218108507667, \"b\": -9.916477905615276, \"c\": 2}, {\"a\": -0.363415550043525, \"b\": 0.9239371160539462, \"c\": 0}, {\"a\": 0.39161353690892486, \"b\": 4.992151869015544, \"c\": 4}, {\"a\": -9.245910150739688, \"b\": -7.550962977085507, \"c\": 2}, {\"a\": -1.729735371619542, \"b\": 2.478764726975081, \"c\": 3}, {\"a\": -6.74686788723857, \"b\": -9.043499656732294, \"c\": 2}, {\"a\": -6.502048281806927, \"b\": -3.8162615688588457, \"c\": 2}, {\"a\": -0.5727531544913438, \"b\": 0.8063462062388146, \"c\": 0}, {\"a\": -10.175344699636652, \"b\": -5.463804922450773, \"c\": 2}, {\"a\": -4.106858702396426, \"b\": -2.3408221298012126, \"c\": 1}, {\"a\": -6.563452593764408, \"b\": -8.631842178485229, \"c\": 2}, {\"a\": -7.524599864695807, \"b\": -6.447744586868603, \"c\": 2}, {\"a\": -6.506079195472627, \"b\": -9.658119388403557, \"c\": 2}, {\"a\": -1.855638235316565, \"b\": -0.9880734005635787, \"c\": 1}, {\"a\": -8.388627594886293, \"b\": -7.936895147003571, \"c\": 2}, {\"a\": -4.770273905781911, \"b\": -3.66721243167069, \"c\": 2}, {\"a\": -10.266083807773677, \"b\": -4.085024173650223, \"c\": 2}, {\"a\": -2.869192100740044, \"b\": 0.1297524646857532, \"c\": 1}, {\"a\": -1.3768841937000993, \"b\": 3.580392436995841, \"c\": 4}, {\"a\": -9.031173253424043, \"b\": -3.2402994970599357, \"c\": 2}, {\"a\": -2.687930509098118, \"b\": 0.25597365293044405, \"c\": 1}, {\"a\": -1.7695513961121263, \"b\": 4.415038814279186, \"c\": 4}, {\"a\": -5.9749705706712914, \"b\": -4.945426881363112, \"c\": 2}, {\"a\": -1.9835673095886754, \"b\": 4.208998111862698, \"c\": 4}, {\"a\": -1.3748117950994616, \"b\": 4.6689573143064305, \"c\": 4}, {\"a\": -4.604605918692275, \"b\": -0.11362683025389786, \"c\": 1}, {\"a\": -8.053846640749276, \"b\": -9.103091964111703, \"c\": 2}, {\"a\": -2.3654004133508035, \"b\": 5.599175936597855, \"c\": 4}, {\"a\": -2.8102945650568354, \"b\": 0.8243853867336027, \"c\": 1}, {\"a\": -6.8651226284651115, \"b\": -7.220506690935953, \"c\": 2}, {\"a\": -1.7700069323658358, \"b\": 3.789127805130801, \"c\": 4}, {\"a\": -6.416957371344821, \"b\": -9.50487748994172, \"c\": 2}, {\"a\": -5.920135286050662, \"b\": -3.8848507086343735, \"c\": 2}, {\"a\": -5.9654779702419205, \"b\": -0.17147669626593665, \"c\": 1}, {\"a\": -1.9696766794665796, \"b\": 1.9716521047360227, \"c\": 3}, {\"a\": -10.360324591230361, \"b\": -5.438504998688659, \"c\": 2}, {\"a\": -3.4154855461813716, \"b\": 5.121279466328977, \"c\": 4}, {\"a\": -1.9819771099620271, \"b\": 4.022435514174746, \"c\": 4}, {\"a\": -2.681445850589829, \"b\": 5.201018108444244, \"c\": 4}, {\"a\": -1.4870381796148886, \"b\": 1.056563835782806, \"c\": 1}, {\"a\": -6.901403217043635, \"b\": -2.3166657816983456, \"c\": 2}, {\"a\": -6.705476399520531, \"b\": -3.686754001639283, \"c\": 2}, {\"a\": -10.090144822194688, \"b\": -4.191223812820037, \"c\": 2}, {\"a\": -3.6967611316293145, \"b\": 2.463900687366706, \"c\": 1}, {\"a\": -0.979490066070415, \"b\": 4.08668826994449, \"c\": 4}, {\"a\": -0.7154228371238909, \"b\": -0.4987791846030243, \"c\": 0}, {\"a\": -6.900217117808532, \"b\": -7.375053925524479, \"c\": 2}, {\"a\": -3.0991134965865497, \"b\": 0.43697490948586726, \"c\": 1}, {\"a\": -1.8394610810869503, \"b\": 1.3120052694369577, \"c\": 1}, {\"a\": -9.246375268492617, \"b\": -3.8129531109158545, \"c\": 2}, {\"a\": -10.94862175470387, \"b\": -4.657698878886664, \"c\": 2}, {\"a\": -5.803261504359297, \"b\": -1.7683675464072246, \"c\": 2}, {\"a\": -5.444901395015471, \"b\": -2.2609940308468133, \"c\": 2}, {\"a\": -2.44147158863532, \"b\": 3.9689808860145805, \"c\": 4}, {\"a\": -1.5377386349570825, \"b\": 5.535973776755081, \"c\": 4}, {\"a\": -1.6767294004862834, \"b\": 2.2458223878735346, \"c\": 3}, {\"a\": -0.7848503437559591, \"b\": 0.3245787384720506, \"c\": 0}, {\"a\": -8.45850549399804, \"b\": -5.10205277700015, \"c\": 2}, {\"a\": -6.692293595180747, \"b\": -2.957003158621521, \"c\": 2}, {\"a\": -1.9657639185768914, \"b\": 5.234464511450407, \"c\": 4}, {\"a\": -5.26660016153632, \"b\": -6.104817444348344, \"c\": 2}, {\"a\": -1.5988097101490129, \"b\": 4.617614623850878, \"c\": 4}, {\"a\": -2.1766543638687477, \"b\": 3.4094630411928986, \"c\": 4}, {\"a\": -9.313711175471148, \"b\": -4.306758530230219, \"c\": 2}, {\"a\": -5.506193929135358, \"b\": -5.783497915559141, \"c\": 2}, {\"a\": -5.99589621203882, \"b\": -8.362981040046598, \"c\": 2}, {\"a\": -3.489511417040968, \"b\": -0.12710804629235706, \"c\": 1}, {\"a\": -6.48455207105451, \"b\": -9.126495689873284, \"c\": 2}, {\"a\": -7.000118909228632, \"b\": -1.1043742102539231, \"c\": 2}, {\"a\": -10.820179692557353, \"b\": -3.231637255250512, \"c\": 2}, {\"a\": -3.2776254865632373, \"b\": 1.551814853939159, \"c\": 1}, {\"a\": -5.176107271399463, \"b\": -1.9355728377643224, \"c\": 2}, {\"a\": -10.80655970012523, \"b\": -3.3959090945051713, \"c\": 2}, {\"a\": -2.5743192560003485, \"b\": 1.2001081102616435, \"c\": 1}, {\"a\": -1.3006090953384906, \"b\": 2.463589903222341, \"c\": 3}, {\"a\": -6.129808445445476, \"b\": -1.0706636067986812, \"c\": 2}, {\"a\": -4.586411989451577, \"b\": -2.8514610951758512, \"c\": 2}, {\"a\": -6.75506542505025, \"b\": -7.101907336775294, \"c\": 2}, {\"a\": -1.5071178740092803, \"b\": 0.3336792703969858, \"c\": 1}, {\"a\": -9.646595607142135, \"b\": -4.022119010441843, \"c\": 2}, {\"a\": -2.4506386089153462, \"b\": -0.9680376944867533, \"c\": 1}, {\"a\": -5.753983573568844, \"b\": -3.030413575176048, \"c\": 2}, {\"a\": -7.459571864653296, \"b\": -9.325041483845167, \"c\": 2}, {\"a\": -0.25201990570729094, \"b\": 4.535591448553887, \"c\": 4}, {\"a\": -8.132758760144293, \"b\": -8.229907467329777, \"c\": 2}, {\"a\": -0.8205764920740146, \"b\": 5.337591950146718, \"c\": 4}, {\"a\": -7.422396397676752, \"b\": -7.630572930525923, \"c\": 2}, {\"a\": -8.379083216184561, \"b\": -8.395029969946918, \"c\": 2}, {\"a\": -8.042655185190705, \"b\": -7.981270972456454, \"c\": 2}, {\"a\": -2.8964132824899167, \"b\": 5.282328796492461, \"c\": 4}, {\"a\": -1.6894150642840253, \"b\": 0.7543879162358664, \"c\": 1}, {\"a\": -2.675113758829019, \"b\": -0.27983745633866963, \"c\": 1}, {\"a\": 0.5311398230212139, \"b\": 2.510128945952069, \"c\": 3}, {\"a\": -3.712803433994204, \"b\": -0.5869418769779979, \"c\": 1}, {\"a\": -4.377635085060701, \"b\": -4.470176612260914, \"c\": 2}, {\"a\": -11.461766077233694, \"b\": -4.107839741173733, \"c\": 2}, {\"a\": -0.41609942539099376, \"b\": 2.2351078908334108, \"c\": 3}, {\"a\": -5.983791230076191, \"b\": -2.013885710593941, \"c\": 2}, {\"a\": -1.8546172468244206, \"b\": 5.211883293075343, \"c\": 4}, {\"a\": -2.7768702545837973, \"b\": 4.640905566660254, \"c\": 4}, {\"a\": -1.637697069321967, \"b\": 3.93781605256527, \"c\": 4}, {\"a\": -2.4897318012636336, \"b\": 3.5259122689989906, \"c\": 4}, {\"a\": -1.6421504976485148, \"b\": 3.284471140096273, \"c\": 4}, {\"a\": -7.279536025883761, \"b\": -7.131979978525144, \"c\": 2}, {\"a\": -9.59983207877125, \"b\": -4.949359436451604, \"c\": 2}, {\"a\": -7.014565097510603, \"b\": -7.502904890371699, \"c\": 2}, {\"a\": -6.242180289289906, \"b\": -4.36642179422028, \"c\": 2}, {\"a\": -9.199648708354157, \"b\": -4.055280586626805, \"c\": 2}, {\"a\": -8.307689224446381, \"b\": -3.537107114763999, \"c\": 2}, {\"a\": -1.1389835688751488, \"b\": 3.262148479220019, \"c\": 3}, {\"a\": -2.217054627734563, \"b\": 5.3456586130396495, \"c\": 4}, {\"a\": -6.088721255333229, \"b\": -3.2769022925700115, \"c\": 2}, {\"a\": -1.6614513887865232, \"b\": 3.0098694442477294, \"c\": 3}, {\"a\": -7.503082450996407, \"b\": -7.96769248365749, \"c\": 2}, {\"a\": -2.536841424866708, \"b\": 3.5387026459702358, \"c\": 4}, {\"a\": -1.3739725806942609, \"b\": 5.291631033113889, \"c\": 4}, {\"a\": -6.785726730023075, \"b\": -6.512674456068776, \"c\": 2}, {\"a\": -9.113082642398513, \"b\": -7.6693444552827215, \"c\": 2}, {\"a\": -10.067041200343585, \"b\": -4.0617406145367445, \"c\": 2}, {\"a\": -1.5037324569732546, \"b\": -0.14532437444665536, \"c\": 1}, {\"a\": 0.15097500817693676, \"b\": 3.100762946285424, \"c\": 3}, {\"a\": -0.32810279336092774, \"b\": 4.119182005367143, \"c\": 4}, {\"a\": -10.506684781475963, \"b\": -4.119834502249164, \"c\": 2}, {\"a\": -7.241808143454792, \"b\": -1.8710692032636917, \"c\": 2}, {\"a\": -6.450155907830291, \"b\": -8.502212295539598, \"c\": 2}, {\"a\": -5.935307966877595, \"b\": -2.7958543334584736, \"c\": 2}, {\"a\": -10.775571330280513, \"b\": -2.837507439439036, \"c\": 2}, {\"a\": -1.7955372320491088, \"b\": 3.609220083350032, \"c\": 4}, {\"a\": -7.2949962471090055, \"b\": -8.644242537323155, \"c\": 2}, {\"a\": -6.836672118715441, \"b\": -2.7678143758702793, \"c\": 2}, {\"a\": -7.187036198769422, \"b\": -8.834079678641363, \"c\": 2}, {\"a\": -2.966093978792538, \"b\": 4.482870349002754, \"c\": 4}, {\"a\": -5.769432330934028, \"b\": -2.5739206212832006, \"c\": 2}, {\"a\": -2.522952553391356, \"b\": -0.7763711947046121, \"c\": 1}, {\"a\": -11.892979451129568, \"b\": -3.8636194299185536, \"c\": 2}, {\"a\": -1.1444862923091539, \"b\": 1.6239554011902388, \"c\": 3}, {\"a\": -9.040612325531576, \"b\": -8.742159280667789, \"c\": 2}, {\"a\": -6.4584782393539015, \"b\": -5.8595104922668675, \"c\": 2}, {\"a\": -1.1710417594110225, \"b\": 4.330918155822106, \"c\": 4}, {\"a\": -6.881248609399618, \"b\": -8.239654978465852, \"c\": 2}, {\"a\": -6.189512790267436, \"b\": -2.8754561897413904, \"c\": 2}, {\"a\": -6.06644285099233, \"b\": -3.8171355445864172, \"c\": 2}, {\"a\": -7.422069709260755, \"b\": -8.674604490032083, \"c\": 2}, {\"a\": -2.094586392221851, \"b\": 0.06739796642656304, \"c\": 1}, {\"a\": -2.3064765942034278, \"b\": 5.307976760491872, \"c\": 4}, {\"a\": -9.455067209086785, \"b\": -5.911517632962216, \"c\": 2}, {\"a\": -6.093054742617052, \"b\": -2.9364112518201404, \"c\": 2}, {\"a\": -7.766530715821702, \"b\": -8.560597789798429, \"c\": 2}, {\"a\": -6.458333783244444, \"b\": -8.890517732383977, \"c\": 2}, {\"a\": -2.6149851683222085, \"b\": 4.9924002999457775, \"c\": 4}, {\"a\": -10.593798838240764, \"b\": -3.091725446022001, \"c\": 2}, {\"a\": -6.526647969696666, \"b\": -4.415275106915832, \"c\": 2}, {\"a\": -6.616501532876051, \"b\": -7.027904605959791, \"c\": 2}, {\"a\": -8.952718093979204, \"b\": -3.344833848878355, \"c\": 2}, {\"a\": -0.5257904636130821, \"b\": 3.3065986015291307, \"c\": 3}, {\"a\": -6.62326691256588, \"b\": -2.5510803716981574, \"c\": 2}, {\"a\": -6.556897847042359, \"b\": -8.477260433644052, \"c\": 2}, {\"a\": -2.760179083161441, \"b\": 5.551213578682775, \"c\": 4}, {\"a\": -7.686133954087984, \"b\": -7.102613455756773, \"c\": 2}, {\"a\": -2.1660312965873167, \"b\": 0.4441240006567196, \"c\": 1}, {\"a\": 0.04409791461202506, \"b\": 2.389896231159425, \"c\": 3}, {\"a\": -9.604603258799118, \"b\": -5.777268399988398, \"c\": 2}, {\"a\": -1.6860749385907727, \"b\": 0.23663702725395375, \"c\": 1}, {\"a\": -5.9331071735736955, \"b\": -3.2139581237260733, \"c\": 2}, {\"a\": -2.0034135815195953, \"b\": 4.450086725677409, \"c\": 4}, {\"a\": -9.466548710196877, \"b\": -3.949347705387829, \"c\": 2}, {\"a\": -6.085597020621484, \"b\": -1.8648494502221473, \"c\": 2}, {\"a\": -8.79988166193185, \"b\": -2.2487543759907975, \"c\": 2}, {\"a\": -1.055560252714451, \"b\": 0.888307367563667, \"c\": 0}, {\"a\": -9.01276083193389, \"b\": -2.882096119517314, \"c\": 2}, {\"a\": -5.758243306404212, \"b\": -3.3461804556458747, \"c\": 2}, {\"a\": -2.1350475959612787, \"b\": 0.168870578134377, \"c\": 1}, {\"a\": -9.156850945511998, \"b\": -4.056235764936742, \"c\": 2}, {\"a\": -1.1344523098462147, \"b\": 1.1821136666956886, \"c\": 3}, {\"a\": -8.850812127253619, \"b\": -4.00305112652188, \"c\": 2}, {\"a\": -2.924021832304477, \"b\": 1.8063371686338496, \"c\": 1}, {\"a\": -9.587446758256258, \"b\": -3.0934775755662924, \"c\": 2}, {\"a\": -3.532720883583821, \"b\": 5.327104986898117, \"c\": 4}, {\"a\": -2.6540801866377084, \"b\": 1.216569184447363, \"c\": 1}, {\"a\": -6.83106374106285, \"b\": -5.689427268252139, \"c\": 2}, {\"a\": -3.1004359302403595, \"b\": 5.638742939671598, \"c\": 4}, {\"a\": -1.410760744560749, \"b\": 4.109848716472299, \"c\": 4}, {\"a\": -7.319735130901628, \"b\": -8.294138857014204, \"c\": 2}, {\"a\": -9.144430317829368, \"b\": -4.093060277804277, \"c\": 2}], \"data-9e3c5bb93b8ecfed473a86410a84113f\": [{\"a\": -0.463258473242508, \"b\": 0.3696393289515314}, {\"a\": -2.1969265659138584, \"b\": 0.49523066032301855}, {\"a\": -7.462896140028894, \"b\": -4.639039758468414}, {\"a\": -0.9622920207400103, \"b\": 2.1053588521163116}, {\"a\": -1.6049297991410425, \"b\": 4.584578662357468}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.LayerChart(...)"
      ]
     },
     "execution_count": 5,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "X, _ = make_blobs(n_samples=1000, centers=5, n_features=2, random_state = 1)\n",
    "df = pd.DataFrame(X, columns = list(\"ab\"))\n",
    "starting_points = np.array([[0,0],[-2,0],[-4,0],[0,2],[0,4]])\n",
    "kmeans = KMeans(n_clusters = 5, max_iter=1, init=starting_points, n_init = 1)\n",
    "kmeans.fit(X);\n",
    "df[\"c\"] = kmeans.predict(X)\n",
    "chart1 = alt.Chart(df).mark_circle().encode(\n",
    "    x = \"a\",\n",
    "    y = \"b\",\n",
    "    color = \"c:N\"\n",
    ")\n",
    "\n",
    "df_centers = pd.DataFrame(kmeans.cluster_centers_, columns = list(\"ab\"))\n",
    "\n",
    "chart_centers = alt.Chart(df_centers).mark_point().encode(\n",
    "    x = \"a\",\n",
    "    y = \"b\",\n",
    "    color = alt.value(\"black\"),\n",
    "    shape = alt.value(\"diamond\"),\n",
    ")\n",
    "\n",
    "chart1 + chart_centers"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "cd14350b",
   "metadata": {},
   "source": [
    "## Part 1 of the assignment\n",
    "\n",
    "Turn the above into a Streamlit app and make the following changes:\n",
    "* Give the app a title related to K-Means.\n",
    "* Include a slider that lets the user choose the number of iterations.\n",
    "\n",
    "Not to be turned in: are you able to predict how the colors change from one iteration to the next?  It's pretty difficult because there are so many points.  You could try changing 1000 to 100 above and see if it becomes easier."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "aaa3c1d9",
   "metadata": {},
   "source": [
    "## Part 2 of the assignment\n",
    "Deploy your app on Streamlit cloud.  You can follow the [instructions from Week 4](../Week4/deploy.md)."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "3c290e51",
   "metadata": {},
   "source": [
    "## Part 3 of the assignment\n",
    "Start thinking about the final project ([more details here](../Proj/CourseProject.md)).  In particular, think about what dataset you might want to use and where you might find it, what questions you might want to ask about the dataset, and what \"extra\" component (not something covered in Math 10) you might want to include."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "3d1c2587",
   "metadata": {},
   "source": [
    "## Submission\n",
    "For the submission on Canvas, there should be a text entry box, where you should write in the following.\n",
    "1. Link to the shared Streamlit app.  (The running app, not the source code.)\n",
    "1. What dataset(s) are you thinking of using in the project?  (What is in the dataset, and where can you find it?)\n",
    "1. What questions are you considering related to this data?\n",
    "1. What \"extra\" component are you interested in trying to use?"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "0c39ed96",
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.12"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
